@@ -1,5 +1,5 @@
 package Net::Whois::Raw;
-$Net::Whois::Raw::VERSION = '2.99008';
+$Net::Whois::Raw::VERSION = '2.99009';
 # ABSTRACT: Get Whois information of domains and IP addresses.
 
 require 5.008_001;
@@ -204,10 +204,12 @@ sub recursive_whois {
     }
 
     if (
-        # Bypass recursing to custom servers
-        $Net::Whois::Raw::Data::whois_servers_no_recurse{ $newsrv }
-        # Bypass recursing to WHOIS servers with no IDN support
-        || $dom =~ /^xn--/i && $newsrv && $Net::Whois::Raw::Data::whois_servers_with_no_idn_support{ $newsrv }
+        defined $newsrv && (
+            # Bypass recursing to custom servers
+            $Net::Whois::Raw::Data::whois_servers_no_recurse{ $newsrv }
+            # Bypass recursing to WHOIS servers with no IDN support
+            || $dom =~ /^xn--/i && $newsrv && $Net::Whois::Raw::Data::whois_servers_with_no_idn_support{ $newsrv }
+        )
     ) {
         $newsrv = undef;
     }
@@ -476,7 +478,7 @@ Net::Whois::Raw - Get Whois information of domains and IP addresses.
 
 =head1 VERSION
 
-version 2.99008
+version 2.99009
 
 =head1 SYNOPSIS
 
